resource "aws_appsync_resolver" "Mutation_addComment" {
  api_id = aws_appsync_graphql_api.appsync.id
  type   = "Mutation"
  field  = "addComment"
  runtime {
    name            = "APPSYNC_JS"
    runtime_version = "1.0.0"
  }
  code = <<EOF
export function request(ctx) {
	if (util.authType() === "User Pool Authorization" && ctx.identity.sub !== ctx.args.userId) {
		return util.unauthorized();
	}
	return {};
}
export function response(ctx) {
	return ctx.result;
}
EOF
  kind = "PIPELINE"
  pipeline_config {
    functions = [
      aws_appsync_function.Mutation_addComment_1.function_id,
      aws_appsync_function.Mutation_addComment_2.function_id,
      aws_appsync_function.Mutation_addComment_3.function_id,
      aws_appsync_function.Mutation_addComment_4.function_id,
    ]
  }
}
resource "aws_appsync_function" "Mutation_addComment_1" {
  api_id      = aws_appsync_graphql_api.appsync.id
  data_source = aws_appsync_datasource.ddb_post.name
  name        = "Mutation_addComment_1"
  runtime {
    name            = "APPSYNC_JS"
    runtime_version = "1.0.0"
  }
  code = <<EOF
import {util} from "@aws-appsync/utils";
export function request(ctx) {
	return {
		version : "2018-05-29",
		operation : "GetItem",
		key: {
			id: {S: ctx.args.postId}
		}
	};
}
export function response(ctx) {
	if (ctx.error) {
		return util.error(ctx.error.message, ctx.error.type);
	}
	return ctx.result;
}
EOF
}

resource "aws_appsync_function" "Mutation_addComment_2" {
  api_id      = aws_appsync_graphql_api.appsync.id
  data_source = aws_appsync_datasource.ddb_friend.name
  name        = "Mutation_addComment_2"
  runtime {
    name            = "APPSYNC_JS"
    runtime_version = "1.0.0"
  }
  code = <<EOF
import {util, runtime} from "@aws-appsync/utils";
export function request(ctx) {
	// skip friend check for same user
	if (util.authType() !== "User Pool Authorization" || ctx.identity.sub === ctx.prev.result.userId) {
		return runtime.earlyReturn(ctx.prev.result);
	}
	return {
		version : "2018-05-29",
		operation : "GetItem",
		key: {
			userId1: {S: ctx.identity.sub},
			userId2: {S: ctx.prev.result.userId},
		}
	};
}
export function response(ctx) {
	if (ctx.error) {
		return util.error(ctx.error.message, ctx.error.type);
	}
	if(!ctx.result) {
		return util.unauthorized();
	}
	return ctx.prev.result;
}
EOF
}

resource "aws_appsync_function" "Mutation_addComment_3" {
  api_id      = aws_appsync_graphql_api.appsync.id
  data_source = aws_appsync_datasource.ddb_comment.name
  name        = "Mutation_addComment_3"
  runtime {
    name            = "APPSYNC_JS"
    runtime_version = "1.0.0"
  }
  code = <<EOF
import {util} from "@aws-appsync/utils";
export function request(ctx) {
	return {
		version : "2018-05-29",
		operation : "PutItem",
		key : {
			id: {S: util.autoId()}
		},
		attributeValues: {
			userId: {S: ctx.args.userId},
			postId: {S: ctx.args.postId},
			date: {N: util.time.nowEpochMilliSeconds() + ""},
			text: {S: ctx.args.text},
		}
	};
}
export function response(ctx) {
	if (ctx.error) {
		return util.error(ctx.error.message, ctx.error.type);
	}
	return ctx.result;
}
EOF
}

resource "aws_appsync_function" "Mutation_addComment_4" {
  api_id      = aws_appsync_graphql_api.appsync.id
  data_source = aws_appsync_datasource.notify.name
  name        = "Mutation_addComment_4"
  runtime {
    name            = "APPSYNC_JS"
    runtime_version = "1.0.0"
  }
  code = <<EOF
import {util} from "@aws-appsync/utils";
${file("${path.module}/notifyComment.js")}

export function request(ctx) {
	return notifyComment({
		commentId: ctx.prev.result.id,
	});
}

export function response(ctx) {
	const result = JSON.parse(ctx.result.body);
	if (result.errors) {
		return util.error(result.errors[0].message);
	}

	return ctx.prev.result;
}
EOF
}

