resource "aws_appsync_resolver" "Mutation_createPost" {
  api_id = aws_appsync_graphql_api.appsync.id
  type   = "Mutation"
  field  = "createPost"
  runtime {
    name            = "APPSYNC_JS"
    runtime_version = "1.0.0"
  }
  code = <<EOF
export function request(ctx) {
	if (util.authType() === "User Pool Authorization" && ctx.identity.sub !== ctx.args.userId) {
		return util.unauthorized();
	}
	return {};
}
export function response(ctx) {
	return ctx.result;
}
EOF
  kind = "PIPELINE"
  pipeline_config {
    functions = [
      aws_appsync_function.Mutation_createPost_1.function_id,
      aws_appsync_function.Mutation_createPost_2.function_id,
    ]
  }
}
resource "aws_appsync_function" "Mutation_createPost_1" {
  api_id      = aws_appsync_graphql_api.appsync.id
  data_source = aws_appsync_datasource.ddb_post.name
  name        = "Mutation_createPost_1"
  runtime {
    name            = "APPSYNC_JS"
    runtime_version = "1.0.0"
  }
  code = <<EOF
import {util} from "@aws-appsync/utils";
export function request(ctx) {
	return {
		version : "2018-05-29",
		operation : "PutItem",
		key : {
			id: {S: util.autoId()}
		},
		attributeValues: {
			userId: {S: ctx.args.userId},
			date: {N: util.time.nowEpochMilliSeconds() + ""},
			text: {S: ctx.args.text},
		}
	};
}
export function response(ctx) {
	if (ctx.error) {
		return util.error(ctx.error.message, ctx.error.type);
	}
	return ctx.result;
}
EOF
}

resource "aws_appsync_function" "Mutation_createPost_2" {
  api_id      = aws_appsync_graphql_api.appsync.id
  data_source = aws_appsync_datasource.notify.name
  name        = "Mutation_createPost_2"
  runtime {
    name            = "APPSYNC_JS"
    runtime_version = "1.0.0"
  }
  code = <<EOF
import {util} from "@aws-appsync/utils";
${file("${path.module}/notifyPost.js")}

export function request(ctx) {
	return notifyPost({
		postId: ctx.prev.result.id,
	});
}

export function response(ctx) {
	const result = JSON.parse(ctx.result.body);
	if (result.errors) {
		return util.error(result.errors[0].message);
	}

	return ctx.prev.result;
}
EOF
}

