resource "aws_appsync_resolver" "Mutation_notifyComment" {
  api_id = aws_appsync_graphql_api.appsync.id
  type   = "Mutation"
  field  = "notifyComment"
  runtime {
    name            = "APPSYNC_JS"
    runtime_version = "1.0.0"
  }
  code = <<EOF
export function request(ctx) {
	return {};
}
export function response(ctx) {
	return ctx.result;
}
EOF
  kind = "PIPELINE"
  pipeline_config {
    functions = [
      aws_appsync_function.Mutation_notifyComment_1.function_id,
      aws_appsync_function.Mutation_notifyComment_2.function_id,
    ]
  }
}
resource "aws_appsync_function" "Mutation_notifyComment_1" {
  api_id      = aws_appsync_graphql_api.appsync.id
  data_source = aws_appsync_datasource.ddb_comment.name
  name        = "Mutation_notifyComment_1"
  runtime {
    name            = "APPSYNC_JS"
    runtime_version = "1.0.0"
  }
  code = <<EOF
import {util} from "@aws-appsync/utils";
export function request(ctx) {
	return {
		version : "2018-05-29",
		operation : "GetItem",
		key : {
			id: {S: ctx.args.commentId}
		},
	};
}
export function response(ctx) {
	if (ctx.error) {
		return util.error(ctx.error.message, ctx.error.type);
	}
	return ctx.result;
}
EOF
}
resource "aws_appsync_function" "Mutation_notifyComment_2" {
  api_id      = aws_appsync_graphql_api.appsync.id
  data_source = aws_appsync_datasource.ddb_post.name
  name        = "Mutation_notifyComment_2"
  runtime {
    name            = "APPSYNC_JS"
    runtime_version = "1.0.0"
  }
  code = <<EOF
import {util} from "@aws-appsync/utils";
export function request(ctx) {
	return {
		version : "2018-05-29",
		operation : "GetItem",
		key : {
			id: {S: ctx.prev.result.postId}
		},
	};
}
export function response(ctx) {
	if (ctx.error) {
		return util.error(ctx.error.message, ctx.error.type);
	}
	return {
		postUserId: ctx.result.userId,
		postDate: util.time.epochMilliSecondsToISO8601(ctx.result.date),
		comment: ctx.prev.result,
	};
}
EOF
}

