resource "aws_appsync_resolver" "Post_comments" {
  api_id = aws_appsync_graphql_api.appsync.id
  type   = "Post"
  field  = "comments"
  runtime {
    name            = "APPSYNC_JS"
    runtime_version = "1.0.0"
  }
  code = <<EOF
export function request(ctx) {
	return {};
}
export function response(ctx) {
	return ctx.result;
}
EOF
  kind = "PIPELINE"
  pipeline_config {
    functions = [
      aws_appsync_function.Post_comments_1.function_id,
    ]
  }
}
resource "aws_appsync_function" "Post_comments_1" {
  api_id      = aws_appsync_graphql_api.appsync.id
  data_source = aws_appsync_datasource.ddb_comment.name
  name        = "Post_comments_1"
  runtime {
    name            = "APPSYNC_JS"
    runtime_version = "1.0.0"
  }
  code = <<EOF
import {util} from "@aws-appsync/utils";
export function request(ctx) {
	return {
		version : "2018-05-29",
		operation : "Query",
		index: "postId",
		query: {
			expression: "#postId = :postId",
			expressionNames: {
				"#postId": "postId",
			},
			expressionValues: {
				":postId": {S: ctx.source.id},
			},
		},
		scanIndexForward: false,
		nextToken: ctx.args.nextToken,
		limit: ctx.args.limit,
	};
}
export function response(ctx) {
	if (ctx.error) {
		return util.error(ctx.error.message, ctx.error.type);
	}
	return {
		comments: ctx.result.items,
		nextToken: ctx.result.nextToken,
	};
}
EOF
}

