resource "aws_appsync_resolver" "Subscription_post" {
  api_id = aws_appsync_graphql_api.appsync.id
  type   = "Subscription"
  field  = "post"
  runtime {
    name            = "APPSYNC_JS"
    runtime_version = "1.0.0"
  }
  code = <<EOF
export function request(ctx) {
	return {};
}
export function response(ctx) {
	return null;
}
EOF
  kind = "PIPELINE"
  pipeline_config {
    functions = [
      aws_appsync_function.Subscription_post_1.function_id,
    ]
  }
}

resource "aws_appsync_function" "Subscription_post_1" {
  api_id      = aws_appsync_graphql_api.appsync.id
  data_source = aws_appsync_datasource.ddb_friend.name
  name        = "Subscription_post_1"
  runtime {
    name            = "APPSYNC_JS"
    runtime_version = "1.0.0"
  }
  code = <<EOF
import {util, runtime} from "@aws-appsync/utils";
export function request(ctx) {
	// skip friend check for same user
	if (ctx.identity.sub === ctx.args.userId) {
		return runtime.earlyReturn(ctx.prev.result);
	}
	return {
		version : "2018-05-29",
		operation : "GetItem",
		key: {
			userId1: {S: ctx.identity.sub},
			userId2: {S: ctx.args.userId},
		}
	};
}
export function response(ctx) {
	if (ctx.error) {
		return util.error(ctx.error.message, ctx.error.type);
	}
	if(!ctx.result) {
		return util.unauthorized();
	}
	return ctx.prev.result;
}
EOF
}

