resource "aws_appsync_resolver" "User_posts" {
  api_id = aws_appsync_graphql_api.appsync.id
  type   = "User"
  field  = "posts"
  runtime {
    name            = "APPSYNC_JS"
    runtime_version = "1.0.0"
  }
  code = <<EOF
export function request(ctx) {
	return {};
}
export function response(ctx) {
	if (ctx.stash.earlyReturnNull) {
		return null;
	}else {
		return ctx.result;
	}
}
EOF
  kind = "PIPELINE"
  pipeline_config {
    functions = [
      aws_appsync_function.User_posts_1.function_id,
      aws_appsync_function.User_posts_2.function_id,
    ]
  }
}
resource "aws_appsync_function" "User_posts_1" {
  api_id      = aws_appsync_graphql_api.appsync.id
  data_source = aws_appsync_datasource.ddb_friend.name
  name        = "User_posts_1"
  runtime {
    name            = "APPSYNC_JS"
    runtime_version = "1.0.0"
  }
  code = <<EOF
import {util, runtime} from "@aws-appsync/utils";
export function request(ctx) {
	// skip friend check for same user
	if (util.authType() !== "User Pool Authorization" || ctx.identity.sub === ctx.source.id) {
		return runtime.earlyReturn({});
	}
	return {
		version : "2018-05-29",
		operation : "GetItem",
		key: {
			userId1: {S: ctx.identity.sub},
			userId2: {S: ctx.source.id},
		}
	};
}
export function response(ctx) {
	if (ctx.error) {
		return util.error(ctx.error.message, ctx.error.type);
	}
	if(!ctx.result) {
		ctx.stash.earlyReturnNull = true;
		runtime.earlyReturn("null");
	}
	return ctx.result;
}
EOF
}
resource "aws_appsync_function" "User_posts_2" {
  api_id      = aws_appsync_graphql_api.appsync.id
  data_source = aws_appsync_datasource.ddb_post.name
  name        = "User_posts_2"
  runtime {
    name            = "APPSYNC_JS"
    runtime_version = "1.0.0"
  }
  code = <<EOF
import {util, runtime} from "@aws-appsync/utils";
export function request(ctx) {
	if(ctx.stash.earlyReturnNull) {
		runtime.earlyReturn("null");
	}
	return {
		version : "2018-05-29",
		operation : "Query",
		index: "userId",
		query: {
			expression: "#userId = :userId",
			expressionNames: {
				"#userId": "userId",
			},
			expressionValues: {
				":userId": {S: ctx.source.id},
			},
		},
		scanIndexForward: false,
		nextToken: ctx.args.nextToken,
		limit: ctx.args.limit,
	};
}
export function response(ctx) {
	if (ctx.error) {
		return util.error(ctx.error.message, ctx.error.type);
	}
	return {
		posts: ctx.result.items,
		nextToken: ctx.result.nextToken,
	};
}
EOF
}

