import {cognitoLoginUrl, clientId, APIURL} from "./config.mjs";
import {timer} from "rxjs";
import {appsyncRealtime, persistentSubscription} from "appsync-subscription-observable";

export const makePaginatedFetcher = (sendQuery, processItem, fieldNames) => (...args) => async (currentPage = undefined, previousPages = []) => {
	const [currentItems, nextItems] = await Promise.all([
		(async () => {
			return {
				...currentPage,
				[fieldNames.items]: currentPage ? await Promise.all(currentPage[fieldNames.items].map(processItem)) : [],
			}
		})(),
		(async () => {
			if (!currentPage || currentPage[fieldNames.nextToken]) {
				const nextPage = await sendQuery(currentPage?.[fieldNames.nextToken], previousPages, ...args);
				if (nextPage) {
					return makePaginatedFetcher(sendQuery, processItem, fieldNames)(...args)(nextPage, [...previousPages, nextPage[fieldNames.items]]);
				}
			}
		})(),
	]);
	return {
		...currentItems,
		[fieldNames.items]: [...(currentItems[fieldNames.items] ?? []), ...(nextItems?.[fieldNames.items] ?? [])],
		[fieldNames.nextToken]: nextItems ? nextItems[fieldNames.nextToken] : currentItems[fieldNames.nextToken],
	}
}

export const sendAppSyncQuery = (getAccessToken) => async (query, variables) => {
	const url = new URL(APIURL);
	const res = await fetch(APIURL, {
		method: "POST",
		body: JSON.stringify({
			query,
			operationName: "MyQuery",
			variables,
		}),
		headers: {
			"Content-Type": "application/graphql",
			host: url.hostname,
			Authorization: await getAccessToken(),
		},
	});
	if (!res.ok) {
		throw new Error("Failed");
	}
	const resJson = await res.json();
	if (resJson.errors) {
		throw new Error(JSON.stringify(resJson));
	}
	return resJson.data;
};

export const formatDate = (dateString) => new Intl.DateTimeFormat('en-US', {dateStyle: "medium", timeStyle: "medium"}).format(new Date(dateString));

export const connection = appsyncRealtime({APIURL, closeDelay: () => timer(6000)});

export {persistentSubscription, cognitoLoginUrl, clientId, APIURL};

